import { Awaitable, Plugin, postInitialization, SapphireClient } from '@sapphire/framework';
import { ModalSubmitInteraction } from 'discord.js';
export declare class ModalCommandsPlugin extends Plugin {
    static [postInitialization](this: SapphireClient): void;
}
declare module '@sapphire/framework' {
    interface Command {
        /**
         * Runs when a modal is submitted. The modal must have a custom ID in the format:
         * `(command name)--custom ID
         * The double dashes can be changed in the client options, but the separator must always be included in the modal custom ID.
         * @param {ModalSubmitInteraction} interaction The interaction passed down from the modal submit event
         */
        modalRun?(interaction: ModalSubmitInteraction): Awaitable<unknown>;
    }
}
export interface ModalCommandsPluginOptions {
    /**
     * The separator in the modal custom id that separates the command name
     */
    separator?: string;
    /**
     * Allows an empty string as a separator, which is unsafe since every modal interaction will trigger every command.
     */
    unsafeUseAnEmptyStringAsSeparator?: boolean;
}
declare module 'discord.js' {
    interface ClientOptions {
        /**
         * Config options for the modal commands plugin
         */
        modalCommands?: ModalCommandsPluginOptions;
    }
}
